@@ -5,7 +5,6 @@ test_that("Output file of function is correct", {
   test_output_value <- as_markdown(
     read_rdfile(
       path = input_file,
-      pkg_path = "testdoc",
       subclass = "refman_rdfile"
     )
   )
@@ -16,6 +15,24 @@ test_that("Output file of function is correct", {
   )
 })
 
+test_that("System user-defined macros are handled correctly", {
+  input_file <- "testdoc/man/fundoc_with_ud_macro.Rd"
+  comp_file <- "testdoc-md/fundoc_with_ud_macro.md"
+
+  test_output_value <- as_markdown(
+    read_rdfile(
+      path = input_file,
+      subclass = "refman_rdfile"
+    )
+  )
+  test_expected_value <- read_file(comp_file, collapse = "\n")
+  expect_equal(
+    test_output_value,
+    test_expected_value
+  )
+})
+
+
 test_that("Output file of S4 class is correct", {
   input_file <- "testdoc/man/Account-class.Rd"
   comp_file <- "testdoc-md/Account-class.md"
@@ -23,7 +40,6 @@ test_that("Output file of S4 class is correct", {
   test_output_value <- as_markdown(
     read_rdfile(
       path = input_file,
-      pkg_path = "testdoc",
       subclass = "refman_rdfile"
     )
   )
@@ -40,7 +56,6 @@ test_that("Output file of R6 class is correct", {
   test_output_value <- as_markdown(
     read_rdfile(
       path = input_file,
-      pkg_path = "testdoc",
       subclass = "refman_rdfile"
     )
   )
